@@ -8,9 +8,9 @@ from tkinter import DISABLED
 from tkinter import END
 from tkinter import NORMAL
 
-from je_editor.utils.exception.je_editor_exception_tag import file_not_fond_error
-from je_editor.utils.exception.je_editor_exception_tag import je_editor_compiler_not_found_error
-from je_editor.utils.exception.je_editor_exceptions import JEditorExecException
+from je_editor.utils.exception.exception_tags import file_not_fond_error
+from je_editor.utils.exception.exception_tags import je_editor_compiler_not_found_error
+from je_editor.utils.exception.exceptions import JEditorExecException
 
 from je_editor.ui.ui_utils.language_data_module.language_compiler_data_module import language_compiler
 from je_editor.ui.ui_utils.language_data_module.language_param_data_module import language_compiler_param
